pub enum ExternalProgramError {
Command(String),
ForegroundOwnershipUnconfirmed {
message: String,
diagnostic: ForegroundRestorationDiagnostic,
},
}Expand description
Failure while an interactive external program temporarily owns the terminal.
Variants
Command(String)
Ordinary command failure after terminal ownership was restored.
ForegroundOwnershipUnconfirmed
Fatal failure because Tau could not confirm foreground ownership.
Fields

diagnostic: ForegroundRestorationDiagnosticBounded private diagnostic for the failed restoration syscall.
Implementations
Sourceimpl ExternalProgramError
impl ExternalProgramError
Sourcepub fn is_foreground_ownership_unconfirmed(&self) -> bool
pub fn is_foreground_ownership_unconfirmed(&self) -> bool
Returns whether the interactive attachment must exit without resuming.
Sourcepub fn foreground_restoration_diagnostic(
&self,
) -> Option<ForegroundRestorationDiagnostic>
pub fn foreground_restoration_diagnostic( &self, ) -> Option<ForegroundRestorationDiagnostic>
Returns the bounded restoration diagnostic for an ownership fail-stop.