pub struct OutputSnapshot { /* private fields */ }Expand description
Snapshot of terminal output zones, excluding prompt input/history state.
Implementations
Sourceimpl OutputSnapshot
impl OutputSnapshot
Sourcepub fn block_count(&self) -> usize
pub fn block_count(&self) -> usize
Returns the number of blocks retained by this presentation model.
Sourcepub fn suggestion_ids(&self) -> &[BlockId]
pub fn suggestion_ids(&self) -> &[BlockId]
Returns the ordered block ids currently present in the suggestions zone.
Sourcepub fn new_block(
&mut self,
debug_id: impl Into<String>,
block: impl Into<StyledBlock>,
) -> BlockId
pub fn new_block( &mut self, debug_id: impl Into<String>, block: impl Into<StyledBlock>, ) -> BlockId
Allocates and stores a block in this output snapshot.
Sourcepub fn set_block(&mut self, id: BlockId, block: impl Into<StyledBlock>)
pub fn set_block(&mut self, id: BlockId, block: impl Into<StyledBlock>)
Replaces one block in this output snapshot.
Sourcepub fn remove_block(&mut self, id: BlockId)
pub fn remove_block(&mut self, id: BlockId)
Removes one block and all of its zone references.
Sourcepub fn push_history(&mut self, id: BlockId)
pub fn push_history(&mut self, id: BlockId)
Appends a block to snapshot history.
Sourcepub fn push_above_active(&mut self, id: BlockId)
pub fn push_above_active(&mut self, id: BlockId)
Appends a block to the snapshot active zone.
Sourcepub fn push_above_active_before_any<I>(&mut self, id: BlockId, anchors: I)where
I: IntoIterator<Item = BlockId>,
pub fn push_above_active_before_any<I>(&mut self, id: BlockId, anchors: I)where
I: IntoIterator<Item = BlockId>,
Moves a block before the first matching snapshot active-zone anchor.
Sourcepub fn push_above_sticky(&mut self, id: BlockId)
pub fn push_above_sticky(&mut self, id: BlockId)
Appends a block to the snapshot sticky zone.
Sourcepub fn remove_above_sticky(&mut self, id: BlockId)
pub fn remove_above_sticky(&mut self, id: BlockId)
Removes a block reference from the snapshot sticky zone.
Sourcepub fn push_below(&mut self, id: BlockId)
pub fn push_below(&mut self, id: BlockId)
Appends a block to the snapshot below-prompt zone.
Sourcepub fn print_output(
&mut self,
debug_id: impl Into<String>,
block: impl Into<StyledBlock>,
) -> BlockId
pub fn print_output( &mut self, debug_id: impl Into<String>, block: impl Into<StyledBlock>, ) -> BlockId
Creates and appends one snapshot history block.